@@ -6,15 +6,15 @@ import json
 import requests
 
 def get_data(urlDict):
-    jobsUrl = urlDict["job"]
-    stagesUrl = urlDict["stage"]
-    tasksUrl = urlDict["task"]
+    jobsUrl = urlDict["jobUrl"]
+    stagesUrl = urlDict["stageUrl"]
+    tasksUrl = urlDict["taskUrl"]
     all_data = []
     for url in [jobsUrl,stagesUrl,tasksUrl]:
         response = requests.get(
             url,
             # params={'duration': '10d'},
-            headers={'Authorization': urlDict["authkey"],'Content-type': 'application/json' },
+            headers={'Authorization': urlDict["authKey"],'Content-type': 'application/json' },
             verify=False
         )
         data = json.loads(response.text)
@@ -85,16 +85,17 @@ def create_mapping(data):
     success_tasks = {i:j for i,j in success_tasks.items() if i in list(all_jobs.keys())}
     return start_stages,success_stages,truncate_stages,start_tasks,success_tasks,truncate_tasks
 
-def work(metricConfig):
-
+def work(metricConfig,filepath):
     # data = []
 
     #GET LOGS FROM ES
     # with open('input/crondata.json' ) as f:
     #     datalogs = json.load(f) 
-    datalogs = get_data(metricConfig.get("url",{}))
-
-    bufferPath = metricConfig.get("buffer_path","bufferdata.json")
+    datalogs = get_data(metricConfig)
+    if "/" in filepath:
+        bufferPath = "/".join(filepath.split("/")[:-1]) + "/bufferdata.json"
+    else:
+        bufferPath = "bufferdata.json"
     if os.path.exists(bufferPath):
         with open(bufferPath, "r") as f:
             try:
